setup_directories: Setup a directory structure for image creation

Description Usage Arguments Value Examples

View source: R/setup_directories.R

Description

I use a certain directory structure for image creation. Every image is saved under "img/everything/". I use the directory "img/handpicked/" for a selection of good images. Moreover I create a directory for the log file. You only need to call this function one time.

Usage

1
setup_directories(img_path, img_subdir, img_subdir2, logfile_dir)

Arguments

img_path

the path, where the images should be saved

img_subdir

one subdirectory

img_subdir2

a second subdirectory

logfile_dir

the log file directory

Value

four dir within your working directory

Examples

1
setup_directories("img/", "everything/", "handpicked/", "logfile/")

samuelwaldman/random documentation built on Dec. 22, 2021, 10:14 p.m.